Crate tower_sessions_rorm_store
source ·Expand description
tower-sessions-rorm-store
Implementation of SessionStore provided by tower_sessions for rorm.
In order to provide the possibility to use a user-defined Model, this crate defines SessionModel which must be implemented to create a RormStore.
Look at our example crate for the usage.
Re-exports
pub use tower_sessions;
Structs
- The session store for rorm
Enums
- Error type that is used in the SessionStore trait
- Represents any valid JSON value.
Traits
- Implement this trait on a Model that should be used to store sessions in a database.